@@ -1,6 +1,6 @@
 package Tool::Bench::Item;
-BEGIN {
-  $Tool::Bench::Item::VERSION = '0.002';
+{
+  $Tool::Bench::Item::VERSION = '0.003';
 }
 use Mouse;
 use List::Util qw{min max sum};
@@ -75,7 +75,7 @@ has code =>
    required => 1,
 ;
 
-has [qw{buildup teardown}] => 
+has [qw{pre_run buildup teardown post_run}] => 
    is => 'ro',
    isa => 'CodeRef',
    default => sub{sub{}},
@@ -87,13 +87,21 @@ has note =>
    default => '',
 ;
 
+=head2 pre_run
+
+An untimed CodeRef that is executed only once before the run is 'executed'.
+
 =head2 buildup
 
 An untimed CodeRef that is executed everytime before 'run' is called.
 
 =head2 teardown
 
-Ain untimed CodeRef that is executed everytime after 'run' is called.
+An untimed CodeRef that is executed everytime after 'run' is called.
+
+=head2 post_run
+
+An untimed CodeRef that is executed only once after the run is 'executed'.
 
 =head2 note
 
